@@ -77,6 +77,11 @@ class Config(object):
     SENTRY_PROJECT_URL = None
     """Sentry project URL. Required to generate links to Sentry in Manager."""
 
+    CLOSE_FDS = True
+    """Patch subprocess.Popen constructor to always set close_fds=True.
+    See `subprocess.Popen <http://docs.python.org/2/library/subprocess.html#popen-constructor>`_
+    for additional information."""
+
     # Connection Options
     ####################
 
