@@ -1,6 +1,8 @@
 from __future__ import absolute_import
+import os
 import sys
 import signal
+import socket
 import logging
 from uuid import uuid1
 from types import MethodType
@@ -11,7 +13,6 @@ from kuyruk import events, importer
 from kuyruk.queue import Queue
 from kuyruk.events import EventMixin
 from kuyruk.helpers import profile
-from kuyruk.channel import LazyChannel
 from kuyruk.exceptions import Timeout
 
 logger = logging.getLogger(__name__)
@@ -93,10 +94,9 @@ class Task(EventMixin):
             queue = self.queue
             local = self.local
 
-        channel = LazyChannel.from_config(self.kuyruk.config)
-        queue = Queue(queue, channel, local)
-        desc = self.get_task_description(args, kwargs, queue.name)
-        with channel:
+        with self.kuyruk.channel() as channel:
+            queue = Queue(queue, channel, local)
+            desc = self.get_task_description(args, kwargs, queue.name)
             queue.send(desc)
 
         return desc['id']
@@ -110,6 +110,7 @@ class Task(EventMixin):
             args[0] = args[0].id
 
         return {
+            'id': uuid1().hex,
             'queue': queue,
             'args': args,
             'kwargs': kwargs,
@@ -117,8 +118,10 @@ class Task(EventMixin):
             'function': self.f.__name__,
             'class': self.class_name,
             'retry': self.retry,
-            'id': uuid1().hex,
-            'timestamp': datetime.utcnow(),
+            'sender_timestamp': datetime.utcnow(),
+            'sender_hostname': socket.gethostname(),
+            'sender_pid': os.getpid(),
+            'sender_cmd': ' '.join(sys.argv),
         }
 
     @profile
@@ -136,9 +139,10 @@ class Task(EventMixin):
         try:
             send_signal(events.task_prerun, reversed(SENDERS))
 
-            with time_limit(
-                    self.max_run_time or
-                    self.kuyruk.config.MAX_TASK_RUN_TIME or 0):
+            limit = (self.max_run_time
+                     or self.kuyruk.config.MAX_TASK_RUN_TIME
+                     or 0)
+            with time_limit(limit):
                 # Call wrapped function
                 return_value = self.f(*args, **kwargs)
         except Exception:
