@@ -7,12 +7,12 @@ import logging
 import traceback
 import multiprocessing
 from time import time, sleep
+from datetime import datetime
 from functools import wraps
 from setproctitle import setproctitle
 import kuyruk
 from kuyruk import importer
 from kuyruk.queue import Queue
-from kuyruk.channel import LazyChannel
 from kuyruk.process import KuyrukProcess
 from kuyruk.helpers import start_daemon_thread
 from kuyruk.consumer import Consumer
@@ -56,9 +56,9 @@ class Worker(KuyrukProcess):
     :param config: A :class:`~kuyurk.config.Config` object
 
     """
-    def __init__(self, config, queue_name):
-        super(Worker, self).__init__(config)
-        self.channel = LazyChannel.from_config(config)
+    def __init__(self, kuyruk, queue_name):
+        super(Worker, self).__init__(kuyruk)
+        self.channel = self.kuyruk._channel()
         is_local = queue_name.startswith('@')
         queue_name = queue_name.lstrip('@')
         self.queue = Queue(queue_name, self.channel, local=is_local)
@@ -217,7 +217,10 @@ class Worker(KuyrukProcess):
         """
         logger.info('Saving failed task')
         task_description['queue'] = self.queue.name
-        task_description['hostname'] = socket.gethostname()
+        task_description['worker_hostname'] = socket.gethostname()
+        task_description['worker_pid'] = os.getpid()
+        task_description['worker_cmd'] = ' '.join(sys.argv)
+        task_description['worker_timestamp'] = datetime.utcnow()
         task_description['exception'] = traceback.format_exc()
         exc_type = sys.exc_info()[0]
         task_description['exception_type'] = "%s.%s" % (
